@@ -1,3 +1,33 @@
+#' 'd3.js' Dependency for Version 5
+#'
+#' @param offline \code{logical} to specify whether to use
+#'         a local copy of d3.js (\code{TRUE}) or use cdn (\code{FALSE})
+#' @return \code{htmltools::htmlDependency}
+#' @export
+#' @examples
+#' library(d3r)
+#' library(htmltools)
+#'
+#' tagList(d3_dep_v5())
+#' @family 'd3' dependency functions
+#' @seealso \code{\link{d3_dep_v4}}, \code{\link{d3_dep_v3}},
+#'   and \code{\link{d3_dep_jetpack}}.
+d3_dep_v5 <- function(offline=TRUE){
+  if(offline) {
+    src = c(file=system.file("www/d3/v5/dist", package="d3r"))
+  } else {
+    src <- c(href="https://unpkg.com/d3@5.0.0-rc.4/dist/")
+  }
+
+  htmltools::htmlDependency(
+    name = "d3",
+    version = "5.0.0",
+    src = src,
+    script = "d3.min.js"
+  )
+}
+
+
 #' 'd3.js' Dependency for Version 4
 #'
 #' @param offline \code{logical} to specify whether to use
@@ -8,17 +38,20 @@
 #' library(d3r)
 #' library(htmltools)
 #'
-#' attachDependencies(tagList(),d3_dep_v4())
+#' tagList(d3_dep_v4())
+#' @family 'd3' dependency functions
+#' @seealso \code{\link{d3_dep_v5}}, \code{\link{d3_dep_v3}},
+#'   and \code{\link{d3_dep_jetpack}}.
 d3_dep_v4 <- function(offline=TRUE){
   if(offline) {
     src = c(file=system.file("www/d3/v4/dist", package="d3r"))
   } else {
-    src <- c(href="https://unpkg.com/d3@4.12.0/build/")
+    src <- c(href="https://unpkg.com/d3@4.13.0/build/")
   }
 
   htmltools::htmlDependency(
     name = "d3",
-    version = "4.12.0",
+    version = "4.13.0",
     src = src,
     script = "d3.min.js"
   )
@@ -34,7 +67,10 @@ d3_dep_v4 <- function(offline=TRUE){
 #' library(d3r)
 #' library(htmltools)
 #'
-#' attachDependencies(tagList(),d3_dep_v3())
+#' tagList(d3_dep_v3())
+#' @family 'd3' dependency functions
+#' @seealso \code{\link{d3_dep_v5}}, \code{\link{d3_dep_v4}},
+#'   and \code{\link{d3_dep_jetpack}}.
 d3_dep_v3 <- function(offline=TRUE){
   if(offline) {
     src = c(file=system.file("www/d3/v3/dist", package="d3r"))
@@ -61,7 +97,7 @@ d3_dep_v3 <- function(offline=TRUE){
 #' @return \code{htmltools::htmlDependency}
 #' @export
 #' @example ./inst/examples/example_d3_jetpack.R
-#'
+#' @family 'd3' dependency functions
 d3_dep_jetpack <- function(offline=TRUE){
 
   if(offline) {
